@@ -15,7 +15,11 @@ import sys
 from datetime import datetime
 from typing import List
 
-from .literals import InstanceAccessControlAttributeConfigurationStatus, PrincipalType, StatusValues
+from .literals import (
+    InstanceAccessControlAttributeConfigurationStatusType,
+    PrincipalTypeType,
+    StatusValuesType,
+)
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -82,7 +86,7 @@ AccessControlAttributeValueTypeDef = TypedDict(
 AccountAssignmentOperationStatusMetadataTypeDef = TypedDict(
     "AccountAssignmentOperationStatusMetadataTypeDef",
     {
-        "Status": StatusValues,
+        "Status": StatusValuesType,
         "RequestId": str,
         "CreatedDate": datetime,
     },
@@ -92,13 +96,13 @@ AccountAssignmentOperationStatusMetadataTypeDef = TypedDict(
 AccountAssignmentOperationStatusTypeDef = TypedDict(
     "AccountAssignmentOperationStatusTypeDef",
     {
-        "Status": StatusValues,
+        "Status": StatusValuesType,
         "RequestId": str,
         "FailureReason": str,
         "TargetId": str,
         "TargetType": Literal["AWS_ACCOUNT"],
         "PermissionSetArn": str,
-        "PrincipalType": PrincipalType,
+        "PrincipalType": PrincipalTypeType,
         "PrincipalId": str,
         "CreatedDate": datetime,
     },
@@ -110,7 +114,7 @@ AccountAssignmentTypeDef = TypedDict(
     {
         "AccountId": str,
         "PermissionSetArn": str,
-        "PrincipalType": PrincipalType,
+        "PrincipalType": PrincipalTypeType,
         "PrincipalId": str,
     },
     total=False,
@@ -168,7 +172,7 @@ DescribeAccountAssignmentDeletionStatusResponseTypeDef = TypedDict(
 DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef = TypedDict(
     "DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef",
     {
-        "Status": InstanceAccessControlAttributeConfigurationStatus,
+        "Status": InstanceAccessControlAttributeConfigurationStatusType,
         "StatusReason": str,
         "InstanceAccessControlAttributeConfiguration": "InstanceAccessControlAttributeConfigurationTypeDef",
     },
@@ -308,7 +312,7 @@ ListTagsForResourceResponseTypeDef = TypedDict(
 OperationStatusFilterTypeDef = TypedDict(
     "OperationStatusFilterTypeDef",
     {
-        "Status": StatusValues,
+        "Status": StatusValuesType,
     },
     total=False,
 )
@@ -326,7 +330,7 @@ PaginatorConfigTypeDef = TypedDict(
 PermissionSetProvisioningStatusMetadataTypeDef = TypedDict(
     "PermissionSetProvisioningStatusMetadataTypeDef",
     {
-        "Status": StatusValues,
+        "Status": StatusValuesType,
         "RequestId": str,
         "CreatedDate": datetime,
     },
@@ -336,7 +340,7 @@ PermissionSetProvisioningStatusMetadataTypeDef = TypedDict(
 PermissionSetProvisioningStatusTypeDef = TypedDict(
     "PermissionSetProvisioningStatusTypeDef",
     {
-        "Status": StatusValues,
+        "Status": StatusValuesType,
         "RequestId": str,
         "AccountId": str,
         "PermissionSetArn": str,
